==> haskell-primitive-extras-0.10.2.2-121.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-extras
version:              0.10.2.2
visibility:           public
id:                   primitive-extras-0.10.2.2-KGar6RA4rs7ETQtyDCkLoS
key:                  primitive-extras-0.10.2.2-KGar6RA4rs7ETQtyDCkLoS
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/primitive-extras
synopsis:             Extras for the "primitive" library
description:
    Raw collection of extra utiltilies for the "primitive" library.

category:             Primitive
abi:                  a283b64211dd6db8d500850785a191a5
exposed:              True
exposed-modules:
    PrimitiveExtras.Bitmap PrimitiveExtras.By6Bits
    PrimitiveExtras.PrimArray PrimitiveExtras.PrimMultiArray
    PrimitiveExtras.SmallArray PrimitiveExtras.UnliftedArray

hidden-modules:
    PrimitiveExtras.FoldMs PrimitiveExtras.Folds
    PrimitiveExtras.Prelude PrimitiveExtras.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/primitive-extras-0.10.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/primitive-extras-0.10.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/primitive-extras-0.10.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-extras
hs-libraries:         HSprimitive-extras-0.10.2.2-KGar6RA4rs7ETQtyDCkLoS
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    deferred-folds-0.9.18.7-3YASkbivcMDDaPil1p3K3o
    focus-1.0.3.2-dqVNbqCJwxApDYKekKDIO
    foldl-1.4.18-DnwxI7jar0n9jaHnbNBdzr
    list-t-1.0.5.7-AhA7x2MdeKdKv2uigYKj0T
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    primitive-unlifted-2.2.0.0-88OuF7gdDeJBuvBXRTStFJ
    profunctors-5.6.3-1wSzWoPhCYk2rkrLUGeSHx
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-primitive-extras/html/primitive-extras.haddock

haddock-html:         /usr/share/doc/haskell-primitive-extras/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-extras-0.10.2.2-122-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-extras
version:              0.10.2.2
visibility:           public
id:                   primitive-extras-0.10.2.2-LthNrCLIOaVFjrl0jUcyR0
key:                  primitive-extras-0.10.2.2-LthNrCLIOaVFjrl0jUcyR0
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/primitive-extras
synopsis:             Extras for the "primitive" library
description:
    Raw collection of extra utiltilies for the "primitive" library.

category:             Primitive
abi:                  d1343b34c2452a335e2cbf4d291c2725
exposed:              True
exposed-modules:
    PrimitiveExtras.Bitmap PrimitiveExtras.By6Bits
    PrimitiveExtras.PrimArray PrimitiveExtras.PrimMultiArray
    PrimitiveExtras.SmallArray PrimitiveExtras.UnliftedArray

hidden-modules:
    PrimitiveExtras.FoldMs PrimitiveExtras.Folds
    PrimitiveExtras.Prelude PrimitiveExtras.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/primitive-extras-0.10.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/primitive-extras-0.10.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/primitive-extras-0.10.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-extras
hs-libraries:         HSprimitive-extras-0.10.2.2-LthNrCLIOaVFjrl0jUcyR0
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    deferred-folds-0.9.18.7-AQVjI6sElLgFSTBjW4DXpU
    focus-1.0.3.2-K7eYaaN3rLJIOKNkem96pr
    foldl-1.4.18-c4zLrEmO0CGifNSU6CYor
    list-t-1.0.5.7-FrIBwXDu8V5JPdGMNO7zz5
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    primitive-unlifted-2.2.0.0-AuFxhNEZbFFJy9FHJWxMPi
    profunctors-5.6.3-11ZlnmbI5xE8sDrL55YXrn
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-primitive-extras/html/primitive-extras.haddock

haddock-html:         /usr/share/doc/haskell-primitive-extras/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
